@@ -36,17 +36,12 @@ public:
     KReportDesignerItemWeb(const QDomNode &element, KReportDesigner *rw, QGraphicsScene *scene);
     ~KReportDesignerItemWeb() override;
 
-    void init(QGraphicsScene *scene);
-
     void buildXML(QDomDocument *doc, QDomElement *parent) override;
     void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget) override;
     KReportDesignerItemWeb *clone() override;
 
-protected:
-    void mousePressEvent(QGraphicsSceneMouseEvent *event) override;
-
 private:
-    void init(QGraphicsScene *, KReportDesigner *r);
+    void init(QGraphicsScene *scene);
 
 private Q_SLOTS:
     void slotPropertyChanged(KPropertySet &, KProperty &);
